summaryrefslogtreecommitdiffstats
path: root/generic/tclCompile.h
diff options
context:
space:
mode:
authormsofer <msofer@noemail.net>2010-04-29 23:39:31 (GMT)
committermsofer <msofer@noemail.net>2010-04-29 23:39:31 (GMT)
commit295578e0d63fa112c62a5873632c646f7bda68bb (patch)
treee43c3dcb657d68ea7a183a4b50ebdd353d55a73a /generic/tclCompile.h
parentd5d232206d0bac8827dbf293b3d8f2b41988dbeb (diff)
downloadtcl-295578e0d63fa112c62a5873632c646f7bda68bb.zip
tcl-295578e0d63fa112c62a5873632c646f7bda68bb.tar.gz
tcl-295578e0d63fa112c62a5873632c646f7bda68bb.tar.bz2
* generic/tclCompExpr.c: Slight change in the literal sharing
* generic/tclCompile.c: mechanism to avoid shimmering of * generic/tclCompile.h: command names. * generic/tclLiteral.c: FossilOrigin-Name: 7ff9813649413276c7880d484fb78768ff39ea23
Diffstat (limited to 'generic/tclCompile.h')
-rw-r--r--generic/tclCompile.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/generic/tclCompile.h b/generic/tclCompile.h
index 1102833..e73ce73 100644
--- a/generic/tclCompile.h
+++ b/generic/tclCompile.h
@@ -9,7 +9,7 @@
* See the file "license.terms" for information on usage and redistribution of
* this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclCompile.h,v 1.124 2010/02/25 14:49:01 dkf Exp $
+ * RCS: @(#) $Id: tclCompile.h,v 1.125 2010/04/29 23:39:32 msofer Exp $
*/
#ifndef _TCLCOMPILATION
@@ -990,7 +990,7 @@ MODULE_SCOPE int TclWordKnownAtCompileTime(Tcl_Token *tokenPtr,
*/
#define LITERAL_ON_HEAP 0x01
-#define LITERAL_NS_SCOPE 0x02
+#define LITERAL_CMD_NAME 0x02
/*
* Form of TclRegisterLiteral with flags == 0. In that case, it is safe to
@@ -1004,7 +1004,7 @@ MODULE_SCOPE int TclWordKnownAtCompileTime(Tcl_Token *tokenPtr,
TclRegisterLiteral(envPtr, (char *)(bytes), length, /*flags*/ 0)
/*
* Form of TclRegisterLiteral with flags == LITERAL_NS_SCOPE. In that case, it
* is safe to cast away constness, and it is cleanest to do that here, all in
* one place.
*
@@ -1012,8 +1012,8 @@ MODULE_SCOPE int TclWordKnownAtCompileTime(Tcl_Token *tokenPtr,
* int length);
*/
-#define TclRegisterNewNSLiteral(envPtr, bytes, length) \
- TclRegisterLiteral(envPtr, (char *)(bytes), length, LITERAL_NS_SCOPE)
+#define TclRegisterNewCmdLiteral(envPtr, bytes, length) \
+ TclRegisterLiteral(envPtr, (char *)(bytes), length, LITERAL_CMD_NAME)
/*
* Macro used to manually adjust the stack requirements; used in cases where
@@ -1004,7 +1004,7 @@ MODULE_SCOPE int TclWordKnownAtCompileTime(Tcl_Token *tokenPtr,
TclRegisterLiteral(envPtr, (char *)(bytes), length, /*flags*/ 0)
/*
- * Form of TclRegisterLiteral with flags == LITERAL_NS_SCOPE. In that case, it
+ * Form of TclRegisterLiteral with flags == LITERAL_CMD_NAME. In that case, it
* is safe to cast away constness, and it is cleanest to do that here, all in
* one place.